@@ -44,7 +44,6 @@ from .config import initialize_logging
 from .core import connect, rpc, CommClosedError, Status
 from .deploy import SpecCluster
 from .metrics import time
-from .process import _cleanup_dangling
 from .proctitle import enable_proctitle_on_children
 from .security import Security
 from .utils import (
@@ -741,7 +740,7 @@ async def disconnect_all(addresses, timeout=3, rpc_kwargs=None):
 
 
 def gen_test(timeout=10):
-    """ Coroutine test
+    """Coroutine test
 
     @gen_test(timeout=5)
     async def test_foo():
@@ -1137,9 +1136,7 @@ async def assert_can_connect_from_everywhere_4_6(port, protocol="tcp", **kwargs)
     await asyncio.gather(*futures)
 
 
-async def assert_can_connect_from_everywhere_4(
-    port, protocol="tcp", **kwargs,
-):
+async def assert_can_connect_from_everywhere_4(port, protocol="tcp", **kwargs):
     """
     Check that the local *port* is reachable from all IPv4 addresses.
     """
@@ -1205,8 +1202,7 @@ async def assert_can_connect_locally_6(port, **kwargs):
 
 @contextmanager
 def captured_logger(logger, level=logging.INFO, propagate=None):
-    """Capture output from the given Logger.
-    """
+    """Capture output from the given Logger."""
     if isinstance(logger, str):
         logger = logging.getLogger(logger)
     orig_level = logger.level
@@ -1228,8 +1224,7 @@ def captured_logger(logger, level=logging.INFO, propagate=None):
 
 @contextmanager
 def captured_handler(handler):
-    """Capture output from the given logging.StreamHandler.
-    """
+    """Capture output from the given logging.StreamHandler."""
     assert isinstance(handler, logging.StreamHandler)
     orig_stream = handler.stream
     handler.stream = io.StringIO()
@@ -1455,7 +1450,6 @@ def check_process_leak(check=True):
         else:
             assert not mp_context.active_children()
 
-    _cleanup_dangling()
     for proc in mp_context.active_children():
         proc.terminate()
 
