@@ -14,7 +14,7 @@ logger = logging.getLogger(__name__)
 
 
 class VariableExtension:
-    """ An extension for the scheduler to manage queues
+    """An extension for the scheduler to manage queues
 
     This adds the following routes to the scheduler
 
@@ -39,7 +39,7 @@ class VariableExtension:
 
         self.scheduler.extensions["variables"] = self
 
-    async def set(self, stream=None, name=None, key=None, data=None, client=None):
+    async def set(self, comm=None, name=None, key=None, data=None, client=None):
         if key is not None:
             record = {"type": "Future", "value": key}
             self.scheduler.client_desires_keys(keys=[key], client="variable-%s" % name)
@@ -71,7 +71,7 @@ class VariableExtension:
             async with self.waiting_conditions[name]:
                 self.waiting_conditions[name].notify_all()
 
-    async def get(self, stream=None, name=None, client=None, timeout=None):
+    async def get(self, comm=None, name=None, client=None, timeout=None):
         start = self.scheduler.loop.time()
         while name not in self.variables:
             if timeout is not None:
@@ -105,7 +105,7 @@ class VariableExtension:
             self.waiting[key, name].add(token)
         return record
 
-    async def delete(self, stream=None, name=None, client=None):
+    async def delete(self, comm=None, name=None, client=None):
         with log_errors():
             try:
                 old = self.variables[name]
@@ -119,9 +119,11 @@ class VariableExtension:
             with suppress(KeyError):
                 del self.variables[name]
 
+            self.scheduler.remove_client("variable-%s" % name)
+
 
 class Variable:
-    """ Distributed Global Variable
+    """Distributed Global Variable
 
     This allows multiple clients to share futures and data between each other
     with a single mutable variable.  All metadata is sequentialized through the
@@ -174,7 +176,7 @@ class Variable:
             await self.client.scheduler.variable_set(data=value, name=self.name)
 
     def set(self, value, **kwargs):
-        """ Set the value of this variable
+        """Set the value of this variable
 
         Parameters
         ----------
@@ -204,7 +206,7 @@ class Variable:
         return value
 
     def get(self, timeout=None, **kwargs):
-        """ Get the value of this variable
+        """Get the value of this variable
 
         Parameters
         ----------
@@ -217,7 +219,7 @@ class Variable:
         return self.client.sync(self._get, timeout=timeout, **kwargs)
 
     def delete(self):
-        """ Delete this variable
+        """Delete this variable
 
         Caution, this affects all clients currently pointing to this variable.
         """
